@@ -1,5 +1,5 @@
 """Translation of IDs with flexible formatting and name matching."""
-from rics.translation import fetching, offline
 from rics.translation._translator import Translator
+from rics.translation.factory import TranslatorFactory
 
-__all__ = ["Translator", "fetching", "offline"]
+__all__ = ["Translator", "TranslatorFactory"]
