@@ -1,13 +1,15 @@
 from typing import Any, Dict, List, Optional, Sequence, TypeVar
 
 import numpy as np
+import pandas as pd
 
 from rics.translation.dio import DataStructureIO
 from rics.translation.dio.exceptions import NotInplaceTranslatableError
 from rics.translation.offline import TranslationMap
 from rics.translation.types import IdType, NameType
+from rics.utility.collections.misc import as_list
 
-T = TypeVar("T", list, np.ndarray, tuple)
+T = TypeVar("T", list, np.ndarray, tuple, pd.Index)
 
 
 class SequenceIO(DataStructureIO):
@@ -15,22 +17,30 @@ class SequenceIO(DataStructureIO):
 
     @staticmethod
     def handles_type(arg: Any) -> bool:
-        return isinstance(arg, (list, np.ndarray, tuple))
+        return isinstance(arg, (list, np.ndarray, tuple, pd.Index))
 
     @staticmethod
     def extract(translatable: T, names: List[NameType]) -> Dict[NameType, Sequence[IdType]]:
-        if len(names) != 1:
-            raise ValueError("Length of names must be one.")
-
-        return {names[0]: list(translatable)}
+        verify_names(len(translatable), names)
+        return (
+            {names[0]: as_list(translatable)}
+            if len(names) == 1
+            else {n: as_list(r) for n, r in zip(names, translatable)}
+        )
 
     @staticmethod
     def insert(translatable: T, names: List[NameType], tmap: TranslationMap, copy: bool) -> Optional[T]:
+        verify_names(len(translatable), names)
         t = translate_sequence(translatable, names, tmap)
 
         if copy:
-            clazz = np.array if isinstance(translatable, np.ndarray) else type(translatable)
-            return clazz(t)
+            if isinstance(translatable, pd.Index):
+                ctor = pd.Index
+            elif isinstance(translatable, np.ndarray):
+                ctor = np.array
+            else:
+                ctor = type(translatable)
+            return ctor(t)
 
         try:
             translatable[:] = t[:]  # type: ignore
@@ -43,10 +53,20 @@ def translate_sequence(s: T, names: List[NameType], tmap: TranslationMap) -> Lis
     """Return a translated copy of the sequence `s`."""
     if len(names) == 1:
         return list(map(tmap[names[0]].get, s))
-    elif len(names) == len(s):
-        return [tmap[n].get(idx) for n, idx in zip(names, s)]
-    else:
+
+    return [
+        translate_sequence(element, [name], tmap)  # type: ignore
+        if SequenceIO.handles_type(element)
+        else tmap[name].get(element)
+        for name, element in zip(names, s)
+    ]
+
+
+def verify_names(data_len: int, names: List[NameType]) -> None:  # pragma: no cover
+    """Verify that the length of names is either 1 or equal to the length of the data."""
+    num_names = len(names)
+    if num_names != 1 and num_names != data_len:
         raise ValueError(
-            f"Number of names {len(names)} must be one or equal to the length of the data {len(s)} to "
+            f"Number of names {len(names)} must be 1 or equal to the length of the data ({data_len}) to "
             f"translate, but got {names=}."
         )
