@@ -1,16 +1,17 @@
-"""Translation-specific exceptions."""
+"""Errors and warnings related to fethcing."""
+from typing import Iterable
+
+
+class FetcherWarning(RuntimeWarning):
+    """Base class for ``Fetcher`` warnings."""
 
 
 class FetcherError(RuntimeError):
-    """Base class for fetcher exceptions."""
+    """Base class for ``Fetcher`` exceptions."""
 
 
 class ForbiddenOperationError(FetcherError):
-    """Exception indicating that the fetcher does not support an operation.
-
-    Args:
-        operation: The operation which was not supported.
-    """
+    """Exception indicating that the ``Fetcher`` does not support an operation."""
 
     def __init__(self, operation: str, reason: str = "not supported by this fetcher.") -> None:
         super().__init__(f"Operation '{operation}' " + reason)
@@ -31,3 +32,14 @@ class UnknownIdError(FetcherError):
 
 class UnknownSourceError(FetcherError):
     """Caller requested unknown source(s)."""
+
+    def __init__(self, unknown_sources: Iterable, sources: Iterable) -> None:
+        super().__init__(f"Sources {set(unknown_sources)} not recognized: Known {sources=}.")
+
+
+class DuplicateSourceWarning(FetcherWarning):
+    """Duplicate sources detected."""
+
+
+class DuplicateSourceError(FetcherError):
+    """Multiple translations for the same source received."""
